import { defu } from "defu";
import { parse } from "valibot";
import { createError, useRuntimeConfig, useScript } from "#imports";
export function mockFallbackScript(name, module) {
  console.error(`${name} is provided by ${module}. Check your console to install it or run 'npx nuxi@latest module add ${module}'`);
  return useScript("", { trigger: "manual" });
}
function validateScriptInputSchema(schema, options) {
  if (import.meta.dev) {
    try {
      parse(schema, options);
    } catch (e) {
      createError({
        cause: e,
        message: "Invalid script options"
      });
    }
  }
}
export function registryScript(key, optionsFn, _userOptions) {
  const runtimeConfig = useRuntimeConfig().public.scripts || {};
  const runtimeOptions = runtimeConfig[key];
  const userOptions = Object.assign(_userOptions || {}, runtimeOptions || {});
  const options = optionsFn(userOptions);
  const scriptInput = defu(options.scriptInput, { key });
  const scriptOptions = Object.assign(_userOptions?.scriptOptions || {}, options.scriptOptions || {});
  const init = scriptOptions.beforeInit;
  scriptOptions.beforeInit = () => {
    import.meta.dev && options.schema && validateScriptInputSchema(options.schema, userOptions);
    init?.();
    import.meta.client && options.clientInit?.();
  };
  return useScript(scriptInput, scriptOptions);
}
